@@ -1,31 +1,10 @@
-/** ===========================================================
- * @file
- *
- * This file is a part of KDE project
- *
- *
- * @date   2006-12-09
- * @brief  a tread-safe libraw C++ program interface
- *
- * @author Copyright (C) 2006-2015 by Gilles Caulier
- *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
- * @author Copyright (C) 2006-2013 by Marcel Wiesweg
- *         <a href="mailto:marcel dot wiesweg at gmx dot de">marcel dot wiesweg at gmx dot de</a>
- * @author Copyright (C) 2007-2008 by Guillaume Castagnino
- *         <a href="mailto:casta at xwing dot info">casta at xwing dot info</a>
- *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * ============================================================ */
+/*
+    SPDX-FileCopyrightText: 2006-2015 Gilles Caulier <caulier dot gilles at gmail dot com>
+    SPDX-FileCopyrightText: 2006-2013 Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+    SPDX-FileCopyrightText: 2007-2008 Guillaume Castagnino <casta at xwing dot info>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "kdcraw.h"
 #include "kdcraw_p.h"
@@ -54,7 +33,7 @@ namespace KDcrawIface
 {
 
 KDcraw::KDcraw()
-    : d(new Private(this))
+    : d(new KDcrawPrivate(this))
 {
     m_cancel = false;
 }
@@ -62,7 +41,6 @@ KDcraw::KDcraw()
 KDcraw::~KDcraw()
 {
     cancel();
-    delete d;
 }
 
 QString KDcraw::version()
@@ -126,7 +104,7 @@ bool KDcraw::loadEmbeddedPreview(QByteArray& imgData, const QString& path)
         return false;
     }
 
-    return (Private::loadEmbeddedPreview(imgData, raw));
+    return (KDcrawPrivate::loadEmbeddedPreview(imgData, raw));
 }
 
 bool KDcraw::loadEmbeddedPreview(QByteArray& imgData, const QBuffer& buffer)
@@ -144,7 +122,7 @@ bool KDcraw::loadEmbeddedPreview(QByteArray& imgData, const QBuffer& buffer)
         return false;
     }
 
-    return (Private::loadEmbeddedPreview(imgData, raw));
+    return (KDcrawPrivate::loadEmbeddedPreview(imgData, raw));
 }
 
 bool KDcraw::loadHalfPreview(QImage& image, const QString& path)
@@ -173,7 +151,7 @@ bool KDcraw::loadHalfPreview(QImage& image, const QString& path)
     }
 
 
-    if(!Private::loadHalfPreview(image, raw))
+    if(!KDcrawPrivate::loadHalfPreview(image, raw))
     {
         qCDebug(LIBKDCRAW_LOG) << "Failed to get half preview from LibRaw!";
         return false;
@@ -207,7 +185,7 @@ bool KDcraw::loadHalfPreview(QByteArray& imgData, const QString& path)
 
     QImage image;
 
-    if (!Private::loadHalfPreview(image, raw))
+    if (!KDcrawPrivate::loadHalfPreview(image, raw))
     {
         qCDebug(LIBKDCRAW_LOG) << "KDcraw: failed to get half preview: " << libraw_strerror(ret);
         return false;
@@ -237,7 +215,7 @@ bool KDcraw::loadHalfPreview(QByteArray& imgData, const QBuffer& inBuffer)
 
     QImage image;
 
-    if (!Private::loadHalfPreview(image, raw))
+    if (!KDcrawPrivate::loadHalfPreview(image, raw))
     {
         qCDebug(LIBKDCRAW_LOG) << "KDcraw: failed to get half preview: " << libraw_strerror(ret);
         return false;
@@ -335,7 +313,7 @@ bool KDcraw::rawFileIdentify(DcrawInfoContainer& identify, const QString& path)
         return false;
     }
 
-    Private::fillIndentifyInfo(&raw, identify);
+    KDcrawPrivate::fillIndentifyInfo(&raw, identify);
     raw.recycle();
     return true;
 }
@@ -359,7 +337,7 @@ bool KDcraw::extractRAWData(const QString& filePath, QByteArray& rawData, DcrawI
 
     LibRaw raw;
     // Set progress call back function.
-    raw.set_progress_handler(callbackForLibRaw, d);
+    raw.set_progress_handler(callbackForLibRaw, d.get());
 
     int ret = raw.open_file((const char*)(QFile::encodeName(filePath)).constData());
 
@@ -379,7 +357,11 @@ bool KDcraw::extractRAWData(const QString& filePath, QByteArray& rawData, DcrawI
     d->setProgress(0.3);
 
     raw.imgdata.params.output_bps  = 16;
+#if LIBRAW_COMPILE_CHECK_VERSION_NOTLESS(0, 21)
+    raw.imgdata.rawparams.shot_select = shotSelect;
+#else
     raw.imgdata.params.shot_select = shotSelect;
+#endif
     ret                            = raw.unpack();
 
     if (ret != LIBRAW_SUCCESS)
@@ -414,7 +396,7 @@ bool KDcraw::extractRAWData(const QString& filePath, QByteArray& rawData, DcrawI
 
     d->setProgress(0.6);
 
-    Private::fillIndentifyInfo(&raw, identify);
+    KDcrawPrivate::fillIndentifyInfo(&raw, identify);
 
     if (m_cancel)
     {
@@ -575,3 +557,5 @@ int KDcraw::librawUseGPL3DemosaicPack()
 }
 
 }  // namespace KDcrawIface
+
+#include "moc_kdcraw.cpp"
